pub fn from_value<T>(value: Value) -> Result<T>where
T: DeserializeOwned,Expand description
Deserializes an instance of type T from a Value.
This is useful when you have already parsed a KeyValues structure into a Value
and want to convert it into a typed Rust structure.